"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.desc = exports.command = void 0;

var _os = _interopRequireDefault(require("os"));

var _split = _interopRequireDefault(require("split2"));

var _ulid = require("ulid");

var _utilities = require("./utilities");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createLogFormatter = function createLogFormatter(configuration) {
  var instanceId;

  if (configuration.appendInstanceId) {
    instanceId = (0, _ulid.ulid)();
  }

  var stream = (0, _split.default)(function (line) {
    if (!(0, _utilities.isRoarrLine)(line)) {
      return configuration.excludeOrphans ? '' : line + '\n';
    }

    var message = JSON.parse(line);

    if (configuration.appendHostname) {
      message.context.hostname = _os.default.hostname();
    }

    if (configuration.appendInstanceId) {
      message.context.instanceId = instanceId;
    }

    return JSON.stringify(message) + '\n';
  });
  return stream;
};

var command = 'augment';
exports.command = command;
var desc = 'Augments Roarr logs with additional information.'; // eslint-disable-next-line flowtype/no-weak-types

exports.desc = desc;

var builder = function builder(yargs) {
  return yargs.options({
    'append-hostname': {
      default: false,
      type: 'boolean'
    },
    'append-instance-id': {
      default: false,
      type: 'boolean'
    },
    'exclude-orphans': {
      default: false,
      describe: 'Excludes messages that cannot be recognized as Roarr log message.',
      type: 'boolean'
    }
  });
}; // eslint-disable-next-line flowtype/no-weak-types


exports.builder = builder;

var handler = function handler(argv) {
  process.stdin.pipe(createLogFormatter(argv)).pipe(process.stdout);
};

exports.handler = handler;
//# sourceMappingURL=augment.js.map