"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.desc = exports.command = void 0;

var _split = _interopRequireDefault(require("split2"));

var _chalk = _interopRequireDefault(require("chalk"));

var _prettyjson = _interopRequireDefault(require("prettyjson"));

var _utilities = require("./utilities");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/* eslint-disable quote-props */
var logLevels = {
  '10': 'TRACE',
  '20': 'DEBUG',
  '30': 'INFO',
  '40': 'WARN',
  '50': 'ERROR',
  '60': 'FATAL'
};
/* eslint-enable */

var logLevelColorMap = {
  DEBUG: _chalk.default.gray,
  ERROR: _chalk.default.red,
  FATAL: _chalk.default.red,
  INFO: _chalk.default.cyan,
  TRACE: _chalk.default.gray,
  WARN: _chalk.default.yellow
};

var getLogLevelName = function getLogLevelName(logLevel) {
  return logLevels[logLevel] || 'INFO';
};

var createLogFormatter = function createLogFormatter(configuration) {
  var stream = (0, _split.default)(function (line) {
    if (!(0, _utilities.isRoarrLine)(line)) {
      return configuration.excludeOrphans ? '' : line + '\n';
    }

    var message = JSON.parse(line);
    var formattedMessage = '';
    formattedMessage = '[' + new Date(message.time).toISOString() + ']';

    if (message.context.logLevel && typeof message.context.logLevel === 'number') {
      var logLevelName = getLogLevelName(message.context.logLevel);
      var logLevelColorName = logLevelColorMap[logLevelName];

      if (!logLevelColorName) {
        throw new Error('Unexpected state.');
      }

      formattedMessage += ' ' + logLevelColorName(logLevelName + ' (' + message.context.logLevel + ')');
    }

    if (message.context.package) {
      formattedMessage += ' (@' + message.context.package + ')';
    }

    if (message.context.namespace) {
      formattedMessage += ' (#' + message.context.namespace + ')';
    }

    formattedMessage += ': ' + message.message + '\n';

    if (configuration.includeContext && message.context) {
      /* eslint-disable no-unused-vars */
      var _message$context = message.context,
          tmp0 = _message$context.application,
          tmp1 = _message$context.hostname,
          tmp2 = _message$context.instanceId,
          tmp3 = _message$context.logLevel,
          tmp4 = _message$context.namespace,
          tmp5 = _message$context.package,
          tmp6 = _message$context.package,
          rest = _objectWithoutProperties(_message$context, ["application", "hostname", "instanceId", "logLevel", "namespace", "package", "package"]);
      /* eslint-enable */


      if (Object.keys(rest).length) {
        // eslint-disable-next-line no-console
        formattedMessage += _prettyjson.default.render(rest) + '\n\n';
      }
    }

    return formattedMessage;
  });
  return stream;
};

var command = 'pretty-print';
exports.command = command;
var desc = 'Format logs for user-inspection.'; // eslint-disable-next-line flowtype/no-weak-types

exports.desc = desc;

var builder = function builder(yargs) {
  return yargs.options({
    'exclude-orphans': {
      default: false,
      describe: 'Excludes messages that cannot be recognized as Roarr log message.',
      type: 'boolean'
    },
    'include-context': {
      default: true,
      type: 'boolean'
    }
  });
};

exports.builder = builder;

var handler = function handler(argv) {
  process.stdin.pipe(createLogFormatter(argv)).pipe(process.stdout);
};

exports.handler = handler;
//# sourceMappingURL=pretty-print.js.map